#!/bin/sh
IMAGE="$1"

EXIT_NA=0
EXIT_OPERATIONAL=1  # i.e. unknown
EXIT_FIPS_NONCAPABLE=2
#EXIT_FIPS_CAPABLE=3
EXIT_FIPS_ENFORCED=4

if ! docker run --rm --entrypoint /bin/sh "${IMAGE}" -c "true"
then
	echo "Could not run shell in ${IMAGE}"
	# TODO: implement check for distroless containers (from scratch)
	exit "${EXIT_OPERATIONAL}"
fi

# OpenSSL Checks
if docker run --rm --entrypoint /bin/sh "${IMAGE}" -c "openssl version"
then
	echo "OpenSSL found"

	# Check that AES-128 works fine
	if docker run --rm --entrypoint /bin/sh "${IMAGE}" -c "echo | openssl enc -aes-128-cbc -K 0000000000000000 -iv 0000000000000000 -nosalt -out /dev/null 2>/dev/null"
	then
		echo "AES check successful"
	else
		exit "${EXIT_OPERATIONAL}"
	fi

	# Check for FIPS mode using CAMELLIA-128
	if docker run --rm --entrypoint /bin/sh "${IMAGE}" -c "echo | openssl enc -camellia-128-cbc -K 0000000000000000 -iv 0000000000000000 -nosalt -out /dev/null 2>/dev/null"
	then
		echo "CAMELLIA allowed"
		exit "${EXIT_FIPS_NONCAPABLE}"
	else
		echo "CAMELLIA not working as expected"
	fi
else
	echo "OpenSSL not found"
	exit "${EXIT_NA}"
fi

exit "${EXIT_FIPS_ENFORCED}"
